@@ -74,7 +74,7 @@ class NoValueDB(object):
 		self._db = DB(name)
 
 	def add(self, key):
-		if self._db.get(key) >= 1:
+		if self._db.get(key, 0) >= 1:
 			return False
 		self._db.update(key, 1)
 		return True
